@@ -1,5 +1,5 @@
 """Contains the Messages data structure."""
-from typing import Dict, List, Mapping
+from typing import Dict, List, Mapping, Optional
 
 _GENERAL_SUBJECT = ""
 
@@ -9,8 +9,8 @@ MessageData = Mapping[str, List[str]]
 class Messages:
     """Contains a mapping of subjects to a list of messages."""
 
-    def __init__(self) -> None:
-        self._data: Dict[str, List[str]] = {}
+    def __init__(self, data: Optional[MessageData] = None) -> None:
+        self._data: Dict[str, List[str]] = data or {}
 
     def __bool__(self):
         return self.has_messages
